pitchtools.transpose_pitch_carrier_by_interval
==============================================

.. autofunction:: abjad.tools.pitchtools.transpose_pitch_carrier_by_interval.transpose_pitch_carrier_by_interval
